Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1026)

Unified Diff: third_party/WebKit/Source/web/tests/WebViewTest.cpp

Issue 2526163002: Rename blink::Page's load deferral to suspension (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/web/tests/WebFrameTest.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/web/tests/WebViewTest.cpp
diff --git a/third_party/WebKit/Source/web/tests/WebViewTest.cpp b/third_party/WebKit/Source/web/tests/WebViewTest.cpp
index e00f06aa70a6649aab0bb09558f254099b4e8df7..3cb8d703df557a0d9e11c8eb3c091be0f6efc834 100644
--- a/third_party/WebKit/Source/web/tests/WebViewTest.cpp
+++ b/third_party/WebKit/Source/web/tests/WebViewTest.cpp
@@ -49,7 +49,7 @@
#include "core/loader/DocumentLoader.h"
#include "core/loader/FrameLoadRequest.h"
#include "core/page/Page.h"
-#include "core/page/ScopedPageLoadDeferrer.h"
+#include "core/page/ScopedPageSuspender.h"
#include "core/paint/PaintLayer.h"
#include "core/paint/PaintLayerPainter.h"
#include "core/timing/DOMWindowPerformance.h"
@@ -4142,18 +4142,18 @@ TEST_P(WebViewTest, PasswordFieldEditingIsUserGesture) {
frame->setAutofillClient(0);
}
// Verify that a WebView created with a ScopedPageLoadDeferrer already on the
// stack defers its loads.
-TEST_P(WebViewTest, CreatedDuringLoadDeferral) {
+TEST_P(WebViewTest, CreatedDuringPageSuspension) {
{
WebViewImpl* webView = m_webViewHelper.initialize();
- EXPECT_FALSE(webView->page()->defersLoading());
+ EXPECT_FALSE(webView->page()->suspended());
}
{
- ScopedPageLoadDeferrer deferrer;
+ ScopedPageSuspender suspender;
WebViewImpl* webView = m_webViewHelper.initialize();
- EXPECT_TRUE(webView->page()->defersLoading());
+ EXPECT_TRUE(webView->page()->suspended());
}
}
@@ -4201,23 +4201,23 @@ TEST_P(WebViewTest, SubframeBeforeUnloadUseCounter) {
// Verify that page loads are deferred until all ScopedPageLoadDeferrers are
// destroyed.
-TEST_P(WebViewTest, NestedLoadDeferrals) {
+TEST_P(WebViewTest, NestedPageSuspensions) {
WebViewImpl* webView = m_webViewHelper.initialize();
- EXPECT_FALSE(webView->page()->defersLoading());
+ EXPECT_FALSE(webView->page()->suspended());
{
- ScopedPageLoadDeferrer deferrer;
- EXPECT_TRUE(webView->page()->defersLoading());
+ ScopedPageSuspender suspender;
+ EXPECT_TRUE(webView->page()->suspended());
{
- ScopedPageLoadDeferrer deferrer2;
- EXPECT_TRUE(webView->page()->defersLoading());
+ ScopedPageSuspender suspender2;
+ EXPECT_TRUE(webView->page()->suspended());
}
- EXPECT_TRUE(webView->page()->defersLoading());
+ EXPECT_TRUE(webView->page()->suspended());
}
- EXPECT_FALSE(webView->page()->defersLoading());
+ EXPECT_FALSE(webView->page()->suspended());
}
TEST_P(WebViewTest, ForceAndResetViewport) {
« no previous file with comments | « third_party/WebKit/Source/web/tests/WebFrameTest.cpp ('k') | no next file » | no next file with comments »
@@ -4142,18 +4142,18 @@ TEST_P(WebViewTest, PasswordFieldEditingIsUserGesture) {
frame->setAutofillClient(0);
}
-// Verify that a WebView created with a ScopedPageLoadDeferrer already on the
+// Verify that a WebView created with a ScopedPageSuspender already on the
// stack defers its loads.

Powered by Google App Engine
This is Rietveld 408576698